caliber.regression.base - caliber

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# Source code for caliber.regression.base

    import abc

    class AbstractRegressionModel:
        def __init__(self):
            self._params = None

        @abc.abstractmethod
        def fit(self, *args, **kwargs):
            pass

        @abc.abstractmethod
        def predict(self, *args, **kwargs):
            pass